@@ -2,7 +2,7 @@
     This file is part of LibQtLua.
 
     LibQtLua is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
+    it under the terms of the GNU Lesser General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
@@ -11,7 +11,7 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
+    You should have received a copy of the GNU Lesser General Public License
     along with LibQtLua.  If not, see <http://www.gnu.org/licenses/>.
 
     Copyright (C) 2008, Alexandre Becoulet <alexandre.becoulet@free.fr>
@@ -41,6 +41,18 @@ namespace QtLua {
     return QTLUA_REFNEW(EnumIterator, ls, _mo->enumerator(_index));
   }
 
+  bool Enum::support(Value::Operation c) const
+  {
+    switch (c)
+      {
+      case Value::OpIndex:
+      case Value::OpIterate:
+	return true;
+      default:
+	return false;
+      }
+  }
+
   String Enum::get_value_str() const
   {
     QMetaEnum me = _mo->enumerator(_index);
