@@ -2,7 +2,7 @@
     This file is part of LibQtLua.
 
     LibQtLua is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
+    it under the terms of the GNU Lesser General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
@@ -11,7 +11,7 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
+    You should have received a copy of the GNU Lesser General Public License
     along with LibQtLua.  If not, see <http://www.gnu.org/licenses/>.
 
     Copyright (C) 2008, Alexandre Becoulet <alexandre.becoulet@free.fr>
@@ -56,14 +56,14 @@ Item::~Item()
   assert(!_model);
 }
 
-void Item::move(QtLua::Ref<ListItem> parent)
+void Item::move(const Ref<ListItem> &parent)
 {
   if (_parent)
     remove();
   insert(parent);
 }
 
-void Item::insert(ListItem::ptr parent)
+void Item::insert(const Ref<ListItem> &parent)
 {
   assert(!_parent);
 
